==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/PodAffinityTermBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodAffinityTermBuilder extends PodAffinityTermFluentImpl<PodAffinityTermBuilder> implements VisitableBuilder<PodAffinityTerm,PodAffinityTermBuilder>{
  public PodAffinityTermBuilder() {
    this(false);
  }
  public PodAffinityTermBuilder(Boolean validationEnabled) {
    this(new PodAffinityTerm(), validationEnabled);
  }
  public PodAffinityTermBuilder(PodAffinityTermFluent<?> fluent) {
    this(fluent, false);
  }
  public PodAffinityTermBuilder(PodAffinityTermFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodAffinityTerm(), validationEnabled);
  }
  public PodAffinityTermBuilder(PodAffinityTermFluent<?> fluent,PodAffinityTerm instance) {
    this(fluent, instance, false);
  }
  public PodAffinityTermBuilder(PodAffinityTermFluent<?> fluent,PodAffinityTerm instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withLabelSelector(instance.getLabelSelector());
      fluent.withNamespaceSelector(instance.getNamespaceSelector());
      fluent.withNamespaces(instance.getNamespaces());
      fluent.withTopologyKey(instance.getTopologyKey());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodAffinityTermBuilder(PodAffinityTerm instance) {
    this(instance,false);
  }
  public PodAffinityTermBuilder(PodAffinityTerm instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withLabelSelector(instance.getLabelSelector());
      this.withNamespaceSelector(instance.getNamespaceSelector());
      this.withNamespaces(instance.getNamespaces());
      this.withTopologyKey(instance.getTopologyKey());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodAffinityTermFluent<?> fluent;
  Boolean validationEnabled;
  public PodAffinityTerm build() {
    PodAffinityTerm buildable = new PodAffinityTerm(fluent.getLabelSelector(),fluent.getNamespaceSelector(),fluent.getNamespaces(),fluent.getTopologyKey());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/PodAffinityTermBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodAffinityTermBuilder extends PodAffinityTermFluent<PodAffinityTermBuilder> implements VisitableBuilder<PodAffinityTerm,PodAffinityTermBuilder>{
  public PodAffinityTermBuilder() {
    this(false);
  }
  public PodAffinityTermBuilder(Boolean validationEnabled) {
    this(new PodAffinityTerm(), validationEnabled);
  }
  public PodAffinityTermBuilder(PodAffinityTermFluent<?> fluent) {
    this(fluent, false);
  }
  public PodAffinityTermBuilder(PodAffinityTermFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodAffinityTerm(), validationEnabled);
  }
  public PodAffinityTermBuilder(PodAffinityTermFluent<?> fluent,PodAffinityTerm instance) {
    this(fluent, instance, false);
  }
  public PodAffinityTermBuilder(PodAffinityTermFluent<?> fluent,PodAffinityTerm instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PodAffinityTerm());

    if (instance != null) {
      fluent.withLabelSelector(instance.getLabelSelector());
      fluent.withNamespaceSelector(instance.getNamespaceSelector());
      fluent.withNamespaces(instance.getNamespaces());
      fluent.withTopologyKey(instance.getTopologyKey());
      fluent.withLabelSelector(instance.getLabelSelector());
      fluent.withNamespaceSelector(instance.getNamespaceSelector());
      fluent.withNamespaces(instance.getNamespaces());
      fluent.withTopologyKey(instance.getTopologyKey());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PodAffinityTermBuilder(PodAffinityTerm instance) {
    this(instance,false);
  }
  public PodAffinityTermBuilder(PodAffinityTerm instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PodAffinityTerm());

    if (instance != null) {
      this.withLabelSelector(instance.getLabelSelector());
      this.withNamespaceSelector(instance.getNamespaceSelector());
      this.withNamespaces(instance.getNamespaces());
      this.withTopologyKey(instance.getTopologyKey());
      this.withLabelSelector(instance.getLabelSelector());
      this.withNamespaceSelector(instance.getNamespaceSelector());
      this.withNamespaces(instance.getNamespaces());
      this.withTopologyKey(instance.getTopologyKey());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PodAffinityTermFluent<?> fluent;
  Boolean validationEnabled;
  public PodAffinityTerm build() {
    PodAffinityTerm buildable = new PodAffinityTerm(fluent.buildLabelSelector(),fluent.buildNamespaceSelector(),fluent.getNamespaces(),fluent.getTopologyKey());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
